from pathlib import Path
from .cv import CV
from .init_src import create_folder
from .extract import get_dcs

# DESTINATION_PATH = "src"
consultants_path = "consultants/"
OUTPUT_PATH = "outputs"
ASSET_PATH = "assets"


def make_cvs(dc_list, output_path, asset_path):
    trigrammatic = dc_list[0].identity
    create_folder(f"{output_path}/{trigrammatic}")
    for dc in dc_list:
        cv = CV(
            dossier_competence=dc,
            cv_template_path="templates/index.html",
            anonymous_doc_path="config/anonyme.json",
        )
        output_path_name = (
            f"{output_path}/{trigrammatic}/{dc.identity} {dc.post}"  # noqa:
        )
        if dc.identity.isupper() and len(dc.identity) == 3:
            cv.make_html(output_path_name, anonimize=True)
            cv.make_pdf(output_path_name, asset_path, anonimize=True)
        else:
            cv.make_html(output_path_name, anonimize=False)
            cv.make_pdf(output_path_name, asset_path, anonimize=False)


def export_consultant(consultant):
    consultants_path = "consultants"
    dcs = get_dcs(consultants_path, consultant)
    make_cvs(dcs, OUTPUT_PATH, ASSET_PATH)


def get_consultants():
    consultant_list = []
    path = Path(consultants_path)
    for i in path.iterdir():
        consultant_list.append(i.name)
    return consultant_list


def add_consultant(consultant: str):
    folder_path = Path(f"{consultants_path}/{consultant}")
    folder_path.mkdir(parents=True, exist_ok=True)


def check_consultant(consultant: str):
    file_miss = False
    file_list = [
        "export.yaml",
        "valeur_ajoutee.md",
        "competences_cles.md",
        "diplomes.md",
        "certifications_formations.md",
        "langues.md",
        "animateur.md",
        "missions_significatives.md",
    ]
    for f in file_list:
        path = Path(f"{consultants_path}/{consultant}/{f}")
        if not path.exists():
            file_miss = True
            print(f"{f} is missing.")
    if not file_miss:
        print("All files exist.")
